@@ -35,5 +35,5 @@ def run(runner, debug=False):
             traceback.print_exc(file=sys.stdout)
             print '-'*60
 
-        respond(e, e.message, success=False)
+        respond(e, str(e), success=False)
         exit(1)
